==> rc-ui-lib-0.1.51.tgz: package/es/overlay/Overlay.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useContext, useRef } from 'react';
import { CSSTransition } from 'react-transition-group';
import classnames from 'classnames';
import { noop, preventDefault, isDef } from '../utils';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var Overlay = function Overlay(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('overlay', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var nodeRef = useRef(null);
  var visible = props.visible,
      duration = props.duration,
      customStyle = props.customStyle,
      children = props.children,
      lockScroll = props.lockScroll;

  var preventTouchMove = function preventTouchMove(event) {
    preventDefault(event, true);
  };

  var renderOverlay = function renderOverlay() {
    var style = _objectSpread(_objectSpread({
      zIndex: props.zIndex !== undefined ? +props.zIndex : undefined
    }, props.style), customStyle);

    if (isDef(duration)) {
      style.animationDuration = "".concat(duration, "ms");
    }

    return /*#__PURE__*/React.createElement("div", {
      ref: nodeRef,
      style: style,
      onClick: props.onClick,
      className: classnames(bem(), props.className),
      onTouchMove: lockScroll ? preventTouchMove : noop
    }, children);
  };

  return /*#__PURE__*/React.createElement(CSSTransition, {
    nodeRef: nodeRef,
    mountOnEnter: true,
    unmountOnExit: true,
    in: visible,
    timeout: duration,
    classNames: "rc-fade"
  }, renderOverlay());
};

Overlay.defaultProps = {
  lockScroll: true,
  duration: 300
};
export default Overlay;

==> rc-ui-lib-0.1.54.tgz: package/es/overlay/Overlay.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React, { useEffect, useContext, useRef } from 'react';
import { CSSTransition } from 'react-transition-group';
import classnames from 'classnames';
import { noop, preventDefault, isDef } from '../utils';
import useLockScroll from '../hooks/use-lock-scroll';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';

var Overlay = function Overlay(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('overlay', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var nodeRef = useRef(null);

  var _useLockScroll = useLockScroll(function () {
    return props.lockScroll;
  }),
      _useLockScroll2 = _slicedToArray(_useLockScroll, 2),
      lockScroll = _useLockScroll2[0],
      unlockScroll = _useLockScroll2[1];

  var visible = props.visible,
      duration = props.duration,
      customStyle = props.customStyle,
      children = props.children;

  var preventTouchMove = function preventTouchMove(event) {
    preventDefault(event, true);
  };

  useEffect(function () {
    if (!props.lockScroll) return;

    if (visible) {
      lockScroll();
    } else {
      unlockScroll();
    }
  }, [visible]);

  var renderOverlay = function renderOverlay() {
    var style = _objectSpread(_objectSpread({
      zIndex: props.zIndex !== undefined ? +props.zIndex : undefined
    }, props.style), customStyle);

    if (isDef(duration)) {
      style.animationDuration = "".concat(duration, "ms");
    }

    return /*#__PURE__*/React.createElement("div", {
      ref: nodeRef,
      style: style,
      onClick: props.onClick,
      className: classnames(bem(), props.className),
      onTouchMove: props.lockScroll ? preventTouchMove : noop
    }, children);
  };

  return /*#__PURE__*/React.createElement(CSSTransition, {
    nodeRef: nodeRef,
    mountOnEnter: true,
    unmountOnExit: true,
    in: visible,
    timeout: duration,
    classNames: "rc-fade"
  }, renderOverlay());
};

Overlay.defaultProps = {
  lockScroll: true,
  duration: 300
};
export default Overlay;
